@@ -1,6 +1,6 @@
 package Device::Cisco::NXAPI;
 
-use 5.006;
+use 5.020;
 use strict;
 use warnings;
 
@@ -24,11 +24,11 @@ Device::Cisco::NXAPI - Interact with the NX-API (Nexus 9K Switches)
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
@@ -155,14 +155,14 @@ The structure returned is as follows:
 
     (
       {
-        'prefix' => '1.1.1.0/24'	                    # The prefix of the route
-        'vrf' => 'other_vrf', 		                    # VRF the route is in.
-        'paths' => [ 				                    # Paths to next-hop (multiple paths in the case of ECMP)
+        'prefix' => '1.1.1.0/24'                        # The prefix of the route
+        'vrf' => 'other_vrf',                           # VRF the route is in.
+        'paths' => []                                   # Paths to next-hop (multiple paths in the case of ECMP)
                      {
-                       'clientname' => 'direct', 		# Protocol (e.g. direct, local, static, ospf)
-                       'uptime' => 'P28DT19H43M28S',	# Time the route has been in the routing table
-                       'ipnexthop' => '2.2.2.1',		# Next hop IP for the path
-                       'ifname' => 'Eth1/1'				# Egress interface for the path
+                       'clientname' => 'direct',        # Protocol (e.g. direct, local, static, ospf)
+                       'uptime' => 'P28DT19H43M28S',    # Time the route has been in the routing table
+                       'ipnexthop' => '2.2.2.1',        # Next hop IP for the path
+                       'ifname' => 'Eth1/1'             # Egress interface for the path
                      }
                    ],
       },
@@ -249,7 +249,7 @@ The structure returned is as follows:
 
     (
      {
-       'ifname' => 'mgmt0',		    # Egress interface
+       'ifname' => 'mgmt0',         # Egress interface
        'vrf' => 'management',		# VRF
        'mac' => '0009.0fe9.9b39',	# MAC address
        'ip' => '10.47.64.4',		# IP address
@@ -363,45 +363,45 @@ sub _modify_returned_vlan_structure {
 Returns a list of HASHREFs containing information on the physical interfacee state.
 
 The structure returned is as follows:
-
-    (
-     {
-       'name' => 'Ethernet1/5',
-       'mac' => '84b8.020f.15d4',
-       'speed' => 'auto-speed',
-       'admin_state' => 'up', 		
-       'op_state' => 'down',	
-       'fps_in' => '0',		
-       'fps_out' => '0',
-       'bps_in' => '0',
-       'bps_out' => '0',
-       'bytes_in' => 0,				
-       'bytes_out' => 0,		
-       'packets_in' => 0,	
-       'packets_out' => 0,
-       'last_link_flap' => 'never'	
-       'errors' => {
-         'ignored_frames' => '0',	
-         'bad_protocol' => '0',
-         'runts' => 0,
-         'crc_errors' => '0',
-         'no_carrier' => '0',
-         'in_errors' => '0',
-         'collisions' => '0',
-         'lost_carrier' => '0',
-         'dribbles' => '0',
-         'overruns' => '0',
-         'bad_frames' => '0',
-         'no_buffer' => 0,
-         'late_collisions' => '0',
-         'underruns' => '0',
-         'out_errors' => '0',
-         'babbles' => '0',
-         'out_discards' => '0',
-         'in_discards' => '0'
-       },
-     }
-    )
+    
+     (
+      {
+        'name' => 'Ethernet1/5',
+        'mac' => '84b8.020f.15d4',
+        'speed' => 'auto-speed',
+        'admin_state' => 'up', 		
+        'op_state' => 'down',	
+        'fps_in' => '0',		
+        'fps_out' => '0',
+        'bps_in' => '0',
+        'bps_out' => '0',
+        'bytes_in' => 0,				
+        'bytes_out' => 0,		
+        'packets_in' => 0,	
+        'packets_out' => 0,
+        'last_link_flap' => 'never'	
+        'errors' => {
+          'ignored_frames' => '0',	
+          'bad_protocol' => '0',
+          'runts' => 0,
+          'crc_errors' => '0',
+          'no_carrier' => '0',
+          'in_errors' => '0',
+          'collisions' => '0',
+          'lost_carrier' => '0',
+          'dribbles' => '0',
+          'overruns' => '0',
+          'bad_frames' => '0',
+          'no_buffer' => 0,
+          'late_collisions' => '0',
+          'underruns' => '0',
+          'out_errors' => '0',
+          'babbles' => '0',
+          'out_discards' => '0',
+          'in_discards' => '0'
+        },
+      }
+     )
 
 =cut
 
@@ -482,6 +482,7 @@ the peer info relating to the default routing table is retrieved. If B<vrf> is s
 from all VRFs (including the global routing table) is returned.
 
 The structure returned is as follows:
+
     (
       {
         'capabilitiessent' => '0',
